@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,7 +22,7 @@ using namespace Gravatar;
 
 Q_GLOBAL_STATIC(GravatarCache, s_gravatarCache)
 
-class Q_DECL_HIDDEN Gravatar::GravatarCachePrivate
+class Gravatar::GravatarCachePrivate
 {
 public:
     template<typename T> inline void insertMissingHash(std::vector<T> &vec, const T &hash)
@@ -80,10 +80,7 @@ GravatarCache::GravatarCache()
     QDir().mkpath(d->mGravatarPath);
 }
 
-GravatarCache::~GravatarCache()
-{
-    delete d;
-}
+GravatarCache::~GravatarCache() = default;
 
 GravatarCache *GravatarCache::self()
 {
@@ -125,7 +122,7 @@ QPixmap GravatarCache::loadGravatarPixmap(const Hash &hash, bool &gravatarStored
     gravatarStored = false;
     // qCDebug(GRAVATAR_LOG) << " hashStr" << hash.hexString();
     if (!hash.isValid()) {
-        return QPixmap();
+        return {};
     }
 
     // in-memory cache
@@ -161,7 +158,7 @@ QPixmap GravatarCache::loadGravatarPixmap(const Hash &hash, bool &gravatarStored
         break;
     }
 
-    return QPixmap();
+    return {};
 }
 
 int GravatarCache::maximumSize() const
