@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
+#include "../src/widgets/gravatardownloadpixmapwidget.h"
 #include <QApplication>
 #include <QCommandLineParser>
-#include "../src/widgets/gravatardownloadpixmapwidget.h"
 #include <QStandardPaths>
 
 int main(int argc, char **argv)
@@ -18,7 +18,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    auto *w = new Gravatar::GravatarDownloadPixmapWidget;
+    auto w = new Gravatar::GravatarDownloadPixmapWidget;
     w->show();
     int ret = app.exec();
     delete w;
